# coding: utf-8

"""
    Kiln API Specifications

    This API provides reporting staking data on various protocols as well as network wide data, staking transaction crafting features and so on. In order to use it, you should first get an API token from your Kiln dashboard (applications section). If you don't have access to our dashboard, please get in touch at hello@kiln.fi. Once you have your API token, you can set it as a bearer token in your request headers.  ### Backward Compatibility  This is an experimental specification used for development and testing, do not rely on what is here unless you know the implications.  The official Kiln API specification following backward compatible changes can be found [here](/).  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: contact@kiln.fi
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import kiln_connect.openapi_client
from kiln_connect.openapi_client.models.ethereum_operation_deposit import EthereumOperationDeposit  # noqa: E501
from kiln_connect.openapi_client.rest import ApiException

class TestEthereumOperationDeposit(unittest.TestCase):
    """EthereumOperationDeposit unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EthereumOperationDeposit
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EthereumOperationDeposit`
        """
        model = kiln_connect.openapi_client.models.ethereum_operation_deposit.EthereumOperationDeposit()  # noqa: E501
        if include_optional :
            return EthereumOperationDeposit(
                type = 'deposit', 
                time = '2023-01-14T01:13:59Z', 
                validator_address = '0x95373bcf8e2c64e1c373a6e534c002f210adbcc84c5abda3b6306677e171430ae50781a51c9f579a47622e334dba2412', 
                tx_hash = '0x43244f90814b31dec250de24df5bb023a338790c1d5a39244cf1064cf6d98c94', 
                tx_sender = '0x41bf25fc8c52d292bd66d3bcecd8a919ecb9ef88', 
                tx_gas_used = '2700999916653262', 
                tx_effective_gas_price = '1499997889', 
                proxies = ["0x1e68238cE926DEC62b3FBC99AB06eB1D85CE0270","0x43244f90814b31dec250de24df5bb023eB1D85CE"], 
                block = 15955054, 
                block_base_fee = '7', 
                withdrawal_credentials = '010000000000000000000000e1f4acc0affb36a805474e3b6ab786738c6900a2', 
                amount = '32000000000000000000000'
            )
        else :
            return EthereumOperationDeposit(
        )
        """

    def testEthereumOperationDeposit(self):
        """Test EthereumOperationDeposit"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
